//---------------------------------------------------------------------------

#ifndef ArmScopeH
#define ArmScopeH
//---------------------------------------------------------------------------

#include "..\miniscope\device\MiniscopeDeviceCapabilities.h"

class ThreadComm;

class ArmScope
{
private:
	enum { VENDOR_ID = 0x03EB };
	enum { PRODUCT_ID = 0x6130 };

	bool bDeviceOpened;
	bool bStopRequest;
	ThreadComm *threadComm;

	typedef void (*CallbackLog)(char*);
	typedef void (*CallbackData)(short*, int);
	typedef void (*CallbackConnect)(int, char*);
	typedef void (*CallbackTrigger)(void);
	void log(char *lpData, ...);

public:
	ArmScope();
	~ArmScope();
	int Connect(void);
	int Disconnect(void);
	int RecStart(void);				///< start recording
	int RecStop(void);              ///< stop recording
	CallbackLog callbackLog;
	CallbackData callbackData;
	CallbackConnect callbackConnect;
	CallbackTrigger callbackTrigger;
	void ConnectCb(int state, char* msg) {
		if (callbackConnect)
			callbackConnect(state, msg);
	}
	/** \brief Request manual triggering
		\return 0 on success
	*/
	int ManualTrigger(void);
	int SetTriggerType(enum E_TRIGGER_TYPE);
	int SetCouplingType(enum E_COUPLING_TYPE);
	/** \brief Set capture buffer size
		\param size number of samples
	*/
	int SetBufferSize(int size);
	int SetSensitivity(int id);
	int SetSampling(int id);
	int SetTriggerLevel(int level);
};
extern ArmScope armScope;


#endif
